@@ -13,6 +13,26 @@ class Reswarm():
         self.cb_connection = CrossbarConnection(self.serial_number, self.quiet)
         self.cb_connection.start()
 
+    def register(self, topic: str, procedure):
+        session = self.cb_connection.getSession()
+        threadedLoop = self.cb_connection.getEventLoop()
+
+        async def registerFunc():
+            return await session.register(topic, procedure)
+
+        concurrentFuture = asyncio.run_coroutine_threadsafe(registerFunc(), threadedLoop)
+        return asyncio.wrap_future(concurrentFuture)
+
+    def subscribe(self, topic: str, handler):
+        session = self.cb_connection.getSession()
+        threadedLoop = self.cb_connection.getEventLoop()
+
+        async def subscribeFunc():
+            return await session.subscribe(handler, topic)
+
+        concurrentFuture = asyncio.run_coroutine_threadsafe(subscribeFunc(), threadedLoop)
+        return asyncio.wrap_future(concurrentFuture)
+
     def publish(self, topic: str, *args: list):
         device_name = os.environ.get("DEVICE_NAME")
 
